@@ -50,11 +50,7 @@
 #include "FileBVH.hh"
 #include <OpenFlipper/BasePlugin/PluginFunctions.hh>
 
-#if QT_VERSION >= 0x050000 
   #include <QtWidgets>
-#else
-  #include <QtGui>
-#endif
 
 #include <sstream>
 
@@ -808,7 +804,4 @@ void FileBVHPlugin::slotLoadDefault() {
 }
 
 //-----------------------------------------------------------------------------------------------------
-#if QT_VERSION < 0x050000
-  Q_EXPORT_PLUGIN2( filebvhplugin , FileBVHPlugin );
-#endif
 
